bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 18. Aventiure
___________________________________________________ #### <Wie Sigmvnt wider ze lande fvr>
| ### er sweher Kriemhilde gie da er si vant ### er sprach ce der kvniginne wir svln in vnser lanc ### wir wæne vnmære geste bi deme Rine sin ### Kriemhilt vil liebiv vrovwe nv vart ir zvo dem lande min
###### 1014 | ### Sid daz vns vntriwe ane hat getan ### hie in disen landen des iwueren edelen man ### des svlt ir niht enkelten ich tvon iv triwen schin ### <durch> iwers mannes liebe vn– des edelen kindes sin
###### 1015 | ### Ir svlt ovch vrovwe haben allen den gewalt ### den iv tet ê Sifrit kvnt der degen balt ### daz lant vnd ovch div krone si iv vndertan ### iv svlen gerne dienen alle Sifrides man
###### 1016 | ### Do seite man den knehten si solden riten dan ### do wart michel gahen nach rossen getan ### bi ir starken vienden was in daz leben leit ### vrowen vn– meiden hiez man suochen div kleit
###### 1017 | ### Do der kvnich Sigmunt wolde sin geriten ### do begvnde Kriemhilt ir mvoter biten ### da si bi ir magen solde da bestan ### do sprach div vrovden arme daz kvnde muolich ergan
###### 1018 | ### Wie moeht ich den immer mit ovgen an gesehen ### von den mir armem wibe so leide ist geschehen ### do sprach der ivnge Giselher liebiv swester min ### dv solt durch din triwe hie bi diner mvoter sin
###### 1019 | ### Die dir hant beswert vn– betrvobet dinen mvot ### der bedarftv niht ze dienste dv cere min eins gvt ### si sprach zuo dem reken ia mag ez niht geschehen ### vor leide mvoz ich sterben swenne ich Hagene solde sehen
###### 1020 | ### Des tvon ich dir ze rate vl liebiv swester min ### dv solt bi dinem bruoder Giselhere sin ### ia wil ich dich ergecen dines mannes tot ### do sprach div gotes arme des wære mnir Kriemhilde not
###### 1021 | ### Do ez ir der ivnge so gvotlich erbot [42a] ### do begvnde doch flegen vote vnde Gernot ### vnd ir getriwe mage si baten si da bestan ### si hete luzel chvnnes vnder Sifrides man
###### 1022 | ### Si sint iv alle vromde so sprach Gernot ### niemen lebet so starker er mvoze ligen tot ### daz bedenket liebiv swester vn– trovstet iweren mvt ### belibet bi den vrivnden ez wirt iv werlichen guot
###### 1023 | ### Si lobete Giselhere si wolde da bestan ### div ros gezogen waren Sigmvndes man ### als si wolden riten ze Niblvnge lant ### ez was vf gesovmet al der reken gewant
###### 1024 | ### Do gie her Sigmvnt fur Kiemhilde stan ### er sprach zuo der vrovwen Sifrides man ### wartent bi den rossen nv svlen wir riten hin ### wan ich vil vngerne hie bi den Burgonden bin
###### 1025 | ### Do sprach vrov Kriemhilt mir ratent vrivnde min ### swaz der ist getriwe ich sul hie bi in sin ### ich habe nimen mage in Niblunge lant ### vil leit was ez Sigmvnde do ers an Kriemhilde vant
###### 1026 | ### Do sprach kvnich Sigmvnt lat ivz nieman sagen ### vor allen minen magen svlt ir krone tragen ### vil gewalteclichen als ir habet ê getan ### ir svlt des niht enkelten daz wir den helt verlorn han
###### 1027 | ### Vnde vart mit vns wider dvrch iwer kindelin ### daz sult ir lan vrovwe niht verweiset sin ### swenne iwer svn gewachset der troestet iv den mvot ### di wile sol iv dienen manich kuene degen guot
###### 1028 | ### Si sprach min her Sigmunt ia mag ich riten niht ### ich mvoz hie beliben swaz halt mir geschit ### bi minen magen die mir helfen klagen ### do begvnden disiv mere den guoten reken missehagen
###### 1029 | ### Si spraken al gelike so moehten wir wol iehen ### daz vns erste wære leide geschehen ### woldet ir beliben bi vnseren vienden hie ### so geriten hovereise noch helde sorchlicher nie
###### 1030 | ### Ir svlt ane sorge got bevolhen varn ### man git iv guot geleite ich heiz iv wol bewarn ### zvo iwerm lande min liebez kindelin ### daz sol vf genade iv guoten reken wol bevolhen sin
###### 1031 | ### Do si wol vernamen daz si niht wolde dan ### do weinde al gelike Sigmvndes man ### wie rehte iæmerlike schiet do Sigmvnt ### von vrovn Kriemhilde do was im vngemvote chvnt
###### 1032 | ### So we der hochzite sprach der kvnich her ### ez geschiht von kvrzwile furbaz nimmer mer ### kvnige noch sinen magen daz vns ist geschehen ### man sol vns nimmer mere hie ze den Burgonden sehen
###### 1033 | ### Do sprachen offenliche Sifrides man ### ez moehte noch div reise in daz lant gan [42b] ### daz wir noch den fvnden der vns den herren sluoch ### si hant von sinen magen stark viende genvoch
###### 1034 | ### Er kvste Kriemhilde iemerlich er sprach ### do si beliben wolde vn– er daz rehte ersach ### nv riten vrovden ane heim in vnser lant ### alle mine sorge sint mir erst nv bekant
###### 1035 | ### Si riten an geleite von Wormz vber Rin ### si mohten wol des mvotes sicherlichen sin ### ob si in vientschefte wrden an gerant ### daz sich weren wolde der kvenen Niblvngen hant
###### 1036 | ### Si gerten vrlovbes da ze heinen man ### do sach Gernoten man vnd Gyselheren gan ### zvo im minneclichen im was sin schade leit ### des brahten in wol innen die helde kuene vn– gemeit
###### 1037 | ### Do sprach gezogenlike der fvrste Gernot ### got weiz wol von himele an Sifrides tot ### gewan ich nie schvlde ich horte ovch nie gesagen ### wer im hie vient were ich sol in bileich klagen
###### 1038 | ### Do gap im gvot geleite Giselher daz kint ### er brahte sorgen ane die noch bi leide sint ### den kvnich bi sinen reken heim ze Niderlant ### wie luzel man der mage darinne vroliche vant
###### 1039 | ### Wie si nv gefueren des kan ich niht gesagen ### man horte hie alle zite Kriemhilde klagen ### daz ir niemen troste daz herze noch den mvot ### ez entete Giselher der was getriwe vnde guot
###### 1040 | ### Prvnhilt div schoene mit vbermvote saz ### swaz geweinde Kriemhilt vmmere was ir daz ### si wart ir gvoter triwen nimmer me bereit ### sid getet ovch ir vrov Kriemhilt vil herzenlichiv leit

<<< Übersicht <<< vorige Seite nächste Seite >>>